searchData={"items":[{"type":"module","title":"EBOR","doc":"The Concise Binary Object Representation (EBOR) is a data format\r\nwhose design goals include the possibility of extremely small code\r\nsize, fairly small message size, and extensibility without the need\r\nfor version negotiation.  These design goals make it different from\r\nearlier binary serializations such as ASN.1 and MessagePack.\r\n\r\nThe objectives of EBOR, roughly in decreasing order of importance are:\r\n\r\n1.  The representation must be able to unambiguously encode most\r\n    common data formats used in Internet standards.\r\n\r\n    *  It must represent a reasonable set of basic data types and\r\n       structures using binary encoding.  \"Reasonable\" here is\r\n       largely influenced by the capabilities of JSON, with the major\r\n       addition of binary byte strings.  The structures supported are\r\n       limited to arrays and trees; loops and lattice-style graphs\r\n       are not supported.\r\n\r\n     *  There is no requirement that all data formats be uniquely\r\n        encoded; that is, it is acceptable that the number \"7\" might\r\n        be encoded in multiple different ways.\r\n\r\n2.  The code for an encoder or decoder must be able to be compact in\r\n    order to support systems with very limited memory, processor\r\n    power, and instruction sets.\r\n\r\n    *  An encoder and a decoder need to be implementable in a very\r\n       small amount of code (for example, in class 1 constrained\r\n       nodes as defined in [CNN-TERMS]).\r\n\r\n    *  The format should use contemporary machine representations of\r\n       data (for example, not requiring binary-to-decimal\r\n       conversion).\r\n\r\n3.  Data must be able to be decoded without a schema description.\r\n\r\n    *  Similar to JSON, encoded data should be self-describing so\r\n        that a generic decoder can be written.\r\n\r\n4.  The serialization must be reasonably compact, but data\r\n    compactness is secondary to code compactness for the encoder and\r\n    decoder.\r\n\r\n    *  \"Reasonable\" here is bounded by JSON as an upper bound in\r\n       size, and by implementation complexity maintaining a lower\r\n       bound.  Using either general compression schemes or extensive\r\n       bit-fiddling violates the complexity goals.\r\n\r\n5.  The format must be applicable to both constrained nodes and high-\r\n    volume applications.\r\n\r\n    *  This means it must be reasonably frugal in CPU usage for both\r\n       encoding and decoding.  This is relevant both for constrained\r\n       nodes and for potential usage in applications with a very high\r\n       volume of data.\r\n\r\n6.  The format must support all JSON data types for conversion to and\r\n    from JSON.\r\n\r\n    *  It must support a reasonable level of conversion as long as\r\n       the data represented is within the capabilities of JSON.  It\r\n       must be possible to define a unidirectional mapping towards\r\n       JSON for all types of data.\r\n\r\n7.  The format must be extensible, and the extended data must be\r\n    decodable by earlier decoders.\r\n\r\n    *  The format is designed for decades of use.\r\n\r\n    *  The format must support a form of extensibility that allows\r\n       fallback so that a decoder that does not understand an\r\n       extension can still decode the message.\r\n\r\n    *  The format must be able to be extended in the future by later\r\n       IETF standards.","ref":"EBOR.html"},{"type":"function","title":"EBOR.decode/1","doc":"Converts a EBOR encoded binary into native elixir data structures","ref":"EBOR.html#decode/1"},{"type":"function","title":"Examples - EBOR.decode/1","doc":"iex> EBOR.decode(<<130, 101, 72, 101, 108, 108, 111, 102, 87, 111, 114, 108, 100, 33>>)\r\n    {:ok, [\"Hello\", \"World!\"], \"\"}\r\n\r\n    iex> EBOR.decode(<<130, 1, 130, 2, 3>>)\r\n    {:ok, [1, [2, 3]], \"\"}\r\n\r\n    iex> EBOR.decode(<<162, 97, 97, 1, 97, 98, 130, 2, 3>>)\r\n    {:ok, %{\"a\" => 1, \"b\" => [2, 3]}, \"\"}","ref":"EBOR.html#decode/1-examples"},{"type":"function","title":"EBOR.encode/1","doc":"Returns a binary encoding of the data in a format\r\nthat can be interpreted by other EBOR libraries.","ref":"EBOR.html#encode/1"},{"type":"function","title":"Examples - EBOR.encode/1","doc":"iex> EBOR.encode([\"Hello\", \"World!\"])\r\n    <<130, 101, 72, 101, 108, 108, 111, 102, 87, 111, 114, 108, 100, 33>>\r\n\r\n    iex> EBOR.encode([1, [2, 3]])\r\n    <<130, 1, 130, 2, 3>>\r\n\r\n    iex> EBOR.encode(%{\"a\" => 1, \"b\" => [2, 3]})\r\n    <<162, 97, 97, 1, 97, 98, 130, 2, 3>>","ref":"EBOR.html#encode/1-examples"},{"type":"module","title":"EBOR.Decoder","doc":"","ref":"EBOR.Decoder.html"},{"type":"function","title":"EBOR.Decoder.decode/1","doc":"","ref":"EBOR.Decoder.html#decode/1"},{"type":"function","title":"EBOR.Decoder.decode/2","doc":"","ref":"EBOR.Decoder.html#decode/2"},{"type":"function","title":"EBOR.Decoder.decode_non_finite/2","doc":"","ref":"EBOR.Decoder.html#decode_non_finite/2"},{"type":"protocol","title":"EBOR.Encoder","doc":"","ref":"EBOR.Encoder.html"},{"type":"function","title":"EBOR.Encoder.encode_into/2","doc":"Converts an Elixir data type to its representation in EBOR.","ref":"EBOR.Encoder.html#encode_into/2"},{"type":"type","title":"EBOR.Encoder.t/0","doc":"All the types that implement this protocol.","ref":"EBOR.Encoder.html#t:t/0"},{"type":"module","title":"EBOR.Tag","doc":"","ref":"EBOR.Tag.html"},{"type":"module","title":"EBOR.Utils","doc":"","ref":"EBOR.Utils.html"},{"type":"function","title":"EBOR.Utils.encode_head/3","doc":"","ref":"EBOR.Utils.html#encode_head/3"},{"type":"function","title":"EBOR.Utils.encode_string/3","doc":"","ref":"EBOR.Utils.html#encode_string/3"},{"type":"extras","title":"EBOR - Enhanced CBOR for Elixir","doc":"# EBOR - Enhanced CBOR for Elixir\n\nEBOR is an optimized CBOR serialization library for Elixir, featuring extended **tuple support up to 255 elements**. Designed for speed, efficiency, and seamless data processing.","ref":"readme.html"},{"type":"extras","title":"🚀 Features - EBOR - Enhanced CBOR for Elixir","doc":"- ⚡ **High-performance** CBOR serialization and deserialization.\n- 🔄 **Extended tuple support** for up to 255 elements.\n- 🔗 **Improved interoperability** with CBOR-based ecosystems.\n- 🎯 **Easy-to-use API** for maximum flexibility.","ref":"readme.html#features"},{"type":"extras","title":"🛠 Installation - EBOR - Enhanced CBOR for Elixir","doc":"Add EBOR to your `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:ebor, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"📌 Usage - EBOR - Enhanced CBOR for Elixir","doc":"Basic serialization and deserialization:\n```elixir\niex> encoded = EBOR.encode({\"message\", 123, 51.89})\n\niex> decoded = EBOR.decode(encoded)\n\niex> decoded\n{:ok, {\"message\", 123, 51.89}, \"\"}\n```","ref":"readme.html#usage"},{"type":"extras","title":"📜 License - EBOR - Enhanced CBOR for Elixir","doc":"This project is released under the MIT license. See LICENSE for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}